@@ -30,10 +30,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <wn.h>
-
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include <string.h>
 
 #ifdef X11_AVAILABLE
 #include <gdk/gdkx.h>
@@ -65,6 +62,12 @@
 #define UI_FILE			"gui.glade"
 #define MAX_CONCAT_STR		500
 #define MAX_STATUS_MSG		100
+/* index.sense reveals that the longest lemma in WordNet is
+ * blood-oxygenation_level_dependent_functional_magnetic_resonance_imaging
+ * 71 chars long; this needs to be updated when WordNet lib. is updated
+ * although it's very hard to beat this one ;)
+ */
+#define MAX_LEMMA_LEN		75
 #define	MAX_SENSE_DIGITS	5
 
 /* about box constants */
@@ -79,26 +82,34 @@
 #define KEY_ACCEL_KEY		"Accel_Key"
 #define KEY_ACCEL_MODS		"Accel_Mods"
 #define KEY_ACCEL_FLAGS		"Accel_Flags"
-#define KEY_VERSION		"Version"
-#define KEY_MODE		"DetailedMode"
+#define KEY_VERSION			"Version"
+#define KEY_MODE			"DetailedMode"
 #define KEY_NOTIFICATIONS	"Notifications"
+#define KEY_POLYSEMY		"Polysemy"
+#define KEY_TRAYICON		"TrayIcon"
+#define KEY_LAUNCH_HIDDEN	"LaunchMinimized"
+#define HISTORY_FILE_EXT	".log"
 
 /* UI element names - refer gui.glade */
-#define WINDOW_MAIN			"wndMain"
+#define WINDOW_MAIN				"wndMain"
 #define BUTTON_SEARCH			"btnSearch"
-#define TEXT_VIEW_DEFINITIONS		"txtDefinitions"
-#define COMBO_QUERY			"cboQuery"
-#define TOOLBAR				"toolbar"
-#define NOTEBOOK			"notebook"
-#define EXPANDER			"expander"
-#define STATUSBAR			"statusbar"
+#define TEXT_VIEW_DEFINITIONS	"txtDefinitions"
+#define COMBO_QUERY				"cboQuery"
+#define TOOLBAR					"toolbar"
+#define NOTEBOOK				"notebook"
+#define EXPANDER				"expander"
+#define STATUSBAR				"statusbar"
 #define LABEL_ATTRIBUTES		"lblAttributes"
-#define LABEL_TEXT_ATTRIBUTES		"Attributes"
-#define LABEL_TEXT_ATTRIBUTE_OF		"Attribute of"
-#define	VPANE				"vpanedMain"
-#define DIALOG_HOTKEY			"dlgHotkeyChooser"
-#define DIALOG_HOTKEY_LABEL		"lblHotkey"
-#define DIALOG_HOTKEY_HBOX		"hboxHotkey"
+#define LABEL_TEXT_ATTRIBUTES	"Attributes"
+#define LABEL_TEXT_ATTRIBUTE_OF	"Attribute of"
+#define	VPANE					"vpanedBody"
+#define DIALOG_OPTIONS			"optionsDialog"
+#define LABEL_HOTKEY			"lblHotkey"
+#define HBOX_HOTKEY				"hboxHotkey"
+#define CHKBTN_POLYSEMY			"chkBtnPolysemy"
+#define CHKBTN_STATUS			"chkBtnStatusIcon"
+#define CHKBTN_LAUNCH_MIN		"chkBtnLaunchMin"
+#define STATUS_ICON				"statusIcon"
 
 /* Relative IDs */
 
@@ -135,8 +146,9 @@
 
 #define STR_TOOLITEM_QUIT	"Q_uit"
 #define STR_TOOLITEM_ABOUT	"_About"
+#define STR_TOOLITEM_TRAYICON "_Tray Icon"
 #define STR_TOOLITEM_NOTIFY	"N_otify"
-#define STR_TOOLITEM_HOTKEY	"_Hotkey"
+#define STR_TOOLITEM_OPTIONS	"Opt_ions"
 #define STR_TOOLITEM_MODE	"_Detailed"
 #define STR_TOOLITEM_NEXT	"_Next"
 #define STR_TOOLITEM_PREV	"_Previous"
@@ -146,8 +158,9 @@
 #define TOOLITEM_TOOLTIP_PREV	"Go to the previous search term"
 #define TOOLITEM_TOOLTIP_NEXT	"Go to the next search term"
 #define TOOLITEM_TOOLTIP_MODE	"Toggle between simple/advanced modes"
-#define TOOLITEM_TOOLTIP_HOTKEY	"View/Modify the hotkey to summon Artha from inside a window, after selecting some text in it"
+#define TOOLITEM_TOOLTIP_OPTIONS "Select preferences like showing polysemy classification and the hotkey to summon Artha from inside a window, after selecting some text in it"
 #define TOOLITEM_TOOLTIP_NOTIFY	"Notify: When on the system tray, if called by the hotkey, instead of popping up, Artha will show a notification of the selected term's definition"
+#define TOOLITEM_TOOLTIP_TRAYICON "Toggle tray icon visibility. Even when invisible, Artha can be summoned using the set hotkey; notifications will continue to work as usual."
 
 #define STR_STATUS_QUERY_SUCCESS "Results returned: %d sense(s) in %d POS(s)!"
 #define STR_MSG_WN_ERROR	"Failed to open WordNet database files!\n\
@@ -162,6 +175,12 @@ Make sure WordNet's database files are present at\n\n%s.\n\nIf present elsewhere
 #define STR_STATUS_REGEX	"%d match(es) found! %s"
 #define STR_STATUS_SEARCHING	"Searching... please wait"
 #define STR_STATUS_REGEX_FILE_MISSING	"Error: index.sense not found!"
+#define STR_HISTORY_FILE_SAVE_SUCCESS	"Lookup history saved successfully."
+#define STR_HISTORY_FILE_SAVE_FAILED		"Failed saving history.\n\nError: %s"
+#define STR_HISTORY_MISSING			"History file missing!"
+#define STR_HISTORY_FILE_UPDATE_FAILED		"Error updating lookup history to file.\nLookups made in this session will not be saved!"
+#define STR_HISTORY_FILE_SAVE_SUCCESS_TITLE "Artha ~ Save successful!"
+#define STR_HISTORY_FILE_SAVE_FAILURE_TITLE "Artha ~ Save failed!"
 
 #define STATUS_DESC_LOADING_INDEX	"loading_index"
 #define STATUS_DESC_SEARCH_SUCCESS	"search_successful"
@@ -186,8 +205,8 @@ currently not set. It can be set via the hotkey button in the toolbar."
 
 #define STR_APP_TITLE		"Artha ~ The Open Thesaurus"
 
-#define STR_COPYRIGHT		"Copyright © 2009, 2010  Sundaram Ramaswamy\n\nWordNet 3.0 \
-Copyright 2006 - 2010 by Princeton University.  All rights reserved."
+#define STR_COPYRIGHT		"Copyright © 2009 - 2012  Sundaram Ramaswamy\n\nWordNet 3.0 \
+Copyright 2006 - 2012 by Princeton University.  All rights reserved."
 
 #define STR_BUG_WEBPAGE		"http://launchpad.net/artha/+filebug"
 
@@ -217,56 +236,5 @@ typedef enum
 } MessageResposeCode;
 
 
-/* Global variables */
-
-gchar *strv_authors[] = {"Sundaram Ramaswamy <legends2k@yahoo.com>", NULL};
-
-/* Names of relative tree tab widgets from UI file
-   Note that the 'tree" prefix will be stripped and will be used within code */
-gchar *relative_tree[] = {"treeSynonyms", "treeAntonyms", "treeDerivatives", "treePertainyms", "treeAttributes", "treeSimilar", 
-"treeDomain", "treeCauses", "treeEntails", "treeHypernyms", "treeHyponyms", "treeHolonyms", "treeMeronyms"};
-
-#define DOMAINS_COUNT (CLASS_END - CLASSIF_START + 1)
-gchar *domain_types[] = {"Topic", "Usage", "Region", "Topic Terms", "Usage Terms", "Regional Terms"};
-
-#define FAMILIARITY_COUNT	8
-gchar *familiarity[] = {"extremely rare","very rare","rare","uncommon","common", "familiar","very familiar","extremely familiar"};
-gchar *freq_colors[] = {"Black", "SaddleBrown", "FireBrick", "SeaGreen", "DarkOrange", "gold", "PaleGoldenrod", "PeachPuff1"};
-/* words for checking familiarity types - none, scroll (v), scroll (n), alright, sequence, set (n), set (v), give */
-
-#ifdef X11_AVAILABLE
-	Display			*dpy = NULL;
-#endif
-GSList 			*results = NULL;
-gchar 			*last_search = NULL;
-gboolean 		was_double_click = FALSE, last_search_successful = FALSE, advanced_mode = FALSE, auto_contract = FALSE;
-gboolean		hotkey_set = FALSE, hotkey_processing = FALSE, notifier_enabled = FALSE, mod_suggest = FALSE;
-#ifdef X11_AVAILABLE
-guint32			last_hotkey_time = 0;
-#endif
-guint 			hotkey_trials[] = {GDK_w, GDK_a, GDK_t, GDK_q};
-guint			num_lock_mask = 0, caps_lock_mask = 0, scroll_lock_mask = 0;
-GtkAccelKey		app_hotkey = {0};
-gint			history_count = 0, notify_toolbar_index = -1;
-guint			status_msg_context_id = 0;
-GString			*wordnet_terms = NULL;
-NotifyNotification	*notifier = NULL;
-GtkCheckMenuItem	*menu_notify = NULL;
-GtkStatusIcon *status_icon = NULL;
-
-#ifdef G_OS_WIN32
-HWND			hMainWindow = NULL;
-#endif
-
-
-/* gtk_show_uri was introduced only in GTK+ 2.14, other than that all other functions referred by 
-   Artha are <= 2.12; hence use gtk_show_uri only if it's available; link it dynamically */
-
-/* dynamically loaded gtk_show_uri function's prototype */
-typedef gboolean (*ShowURIFunc) (GdkScreen *screen, const gchar *uri, guint32 timestamp, GError **error);
-
-/* function ptr to gtk_show_uri */
-ShowURIFunc fp_show_uri = NULL;
-
 #endif		/* __GUI_H__ */
 
