@@ -54,7 +54,7 @@
 extern gboolean	hotkey_processing;
 extern guint32	last_hotkey_time;
 
-guint32
+static guint32
 tomboy_keybinder_get_current_event_time (void)
 {
 	if (hotkey_processing) 
@@ -63,39 +63,12 @@ tomboy_keybinder_get_current_event_time (void)
 		return GDK_CURRENT_TIME;
 }
 
-gint
-tomboy_window_get_workspace (GtkWindow *window)
-{
-	GdkWindow *gdkwin = GTK_WIDGET (window)->window;
-	GdkAtom wm_desktop = gdk_atom_intern ("_NET_WM_DESKTOP", FALSE);
-	GdkAtom out_type;
-	gint out_format, out_length;
-	gulong *out_val;
-	int workspace;
-
-	if (!gdk_property_get (gdkwin,
-			       wm_desktop,
-			       _GDK_MAKE_ATOM (XA_CARDINAL),
-			       0, G_MAXLONG,
-			       FALSE,
-			       &out_type,
-			       &out_format,
-			       &out_length,
-			       (guchar **) &out_val))
-		return -1;
-
-	workspace = *out_val;
-	g_free (out_val);
-
-	return workspace;
-}
-
-void
+static void
 tomboy_window_move_to_current_workspace (GtkWindow *window)
 {
 	GdkWindow *gdkwin = GTK_WIDGET (window)->window;
 	GdkWindow *rootwin = 
-		gdk_screen_get_root_window (gdk_drawable_get_screen (gdkwin));
+		gdk_screen_get_root_window (gdk_window_get_screen (gdkwin));
 
 	GdkAtom current_desktop = 
 		gdk_atom_intern ("_NET_CURRENT_DESKTOP", FALSE);
@@ -129,7 +102,7 @@ tomboy_window_move_to_current_workspace (GtkWindow *window)
 	xev.xclient.window = GDK_WINDOW_XWINDOW (gdkwin);
 	xev.xclient.message_type = 
 		gdk_x11_atom_to_xatom_for_display(
-			gdk_drawable_get_display (gdkwin),
+			gdk_window_get_display (gdkwin),
 			wm_desktop);
 	xev.xclient.format = 32;
 	xev.xclient.data.l[0] = workspace;
@@ -176,9 +149,9 @@ tomboy_window_override_user_time (GtkWindow *window)
 void
 tomboy_window_present_hardcore (GtkWindow *window)
 {
-	if (!GTK_WIDGET_REALIZED (window))
+	if (!gtk_widget_get_realized (GTK_WIDGET (window)))
 		gtk_widget_realize (GTK_WIDGET (window));
-	else if (GTK_WIDGET_VISIBLE (window))
+	else if (gtk_widget_get_visible (GTK_WIDGET (window)))
 		tomboy_window_move_to_current_workspace (window);
 
 	tomboy_window_override_user_time (window);
