@@ -26,13 +26,9 @@
  */
 
 
-/*
-   TODO: When in simple mode, see pertainyms of 'verbally' and hypernyms of
-   'conquest'; Should duplicate check for them in these simple mode cas be 
-   done? Likewise, see 'rupee' Meronyms in Simple mode, it lists cent and 
-   paise around 5 times!
-*/
-
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 #include <wn.h>
@@ -57,7 +53,7 @@ static GSList *find_example(SynsetPtr synptr);
 static gpointer *get_from_global_list(WNIRequestFlags flag);
 static void prune_results(void);
 static WNIDefinitionItem *create_synonym_def(guint8 pos, IndexPtr index, WNIOverview **overview_ptr);
-static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr index, WNIDefinitionItem **def_item_ptr, WNIOverview **overview_ptr, guint8 sense, guint8 pos);
+static void populate_synonyms(WNIDefinitionItem **def_item_ptr, SynsetPtr cursyn, IndexPtr index, WNIOverview **overview_ptr, guint8 sense, guint8 pos);
 static gboolean add_synonym_def(WNIDefinitionItem **def_item_ptr, WNIOverview **overview_ptr, gchar *actual_search);
 static void populate_ptr(gchar *lemma, SynsetPtr synptr, WNIProperties **data_ptr, guint8 ptr, guint8 id, guint8 sense, WNIRequestFlags flag);
 static void grow_tree(gchar *lemma, SynsetPtr synptr, guint8 ptr, GNode **root, guint8 depth);
@@ -78,30 +74,6 @@ static void properties_tree_free(GSList **list, WNIRequestFlags id);
 
 
 
-/*
-	This function is equivalent to g_strcmp0, which is a 
-	wrapper over the standard C lib. function strcmp. The 
-	reason for having it instead of using wni_strcmp0 is that 
-	it was introduced only in glib 2.16. So as to reduce 
-	the version dependency, this function is employed.
-*/
-
-int wni_strcmp0(const char *s1, const char *s2)
-{
-	if(s1 != NULL && s2 != NULL)
-		return strcmp(s1, s2);
-	else
-	{
-		if(s1 == s2)
-			return 0;
-		else if(s1)
-			return 1;
-		else
-			return -1;
-	}
-}
-
-
 /*
 	Checks if depth hasn't exceeded the MAXDEPTH.
 */
@@ -173,7 +145,7 @@ static void populate_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr, gu
 			else								// else create a new antonym item and store the details
 			{
 				//antonym = (WNIAntonymItem*) g_malloc0(sizeof(WNIAntonymItem));
-				antonym = (WNIAntonymItem*) g_slice_alloc0(sizeof(WNIAntonymItem));
+				antonym = g_slice_new0(WNIAntonymItem);
 				antonym->term = g_strdup(cur_synset->words[synptr->pto[i] - 1]);
 				antonym->sense = cur_synset->wnsns[synptr->pto[i] - 1] - 1;				// Second - 1 is to make it count from 0 and not 1
 				antonym->relation = DIRECT_ANT;
@@ -192,12 +164,12 @@ static void populate_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr, gu
 					strsubst(cur_synset->words[j], '_', ' ');
 
 					// check against temp_list too, not only implications, so that we don't miss duplicates in the same list
-					if(wni_strcmp0(antonym->term, cur_synset->words[j]) && 
+					if(g_strcmp0(antonym->term, cur_synset->words[j]) && 
 					(NULL == check_term_in_list(cur_synset->words[j], &antonym->implications, 0)) && 
 					(NULL == check_term_in_list(cur_synset->words[j], &temp_list, 0)))
 					{
 						//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-						implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+						implication = g_slice_new0(WNIImplication);
 						implication->term = g_strdup(cur_synset->words[j]);
 						implication->sense = cur_synset->wnsns[j] - 1;		// Second - 1 is to make it count from 0 and not 1
 
@@ -212,7 +184,7 @@ static void populate_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr, gu
 			}
 
 			//antonym_mapping = (WNIAntonymMapping*) g_malloc0(sizeof(WNIAntonymMapping));
-			antonym_mapping = (WNIAntonymMapping*) g_slice_alloc0(sizeof(WNIAntonymMapping));
+			antonym_mapping = g_slice_new0(WNIAntonymMapping);
 			antonym_mapping->id = id;
 			antonym_mapping->sense = sense;
 			antonym_mapping->related_word_count = count;
@@ -312,7 +284,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 					else
 					{
 						//antonym = (WNIAntonymItem*) g_malloc0(sizeof(WNIAntonymItem));
-						antonym = (WNIAntonymItem*) g_slice_alloc0(sizeof(WNIAntonymItem));
+						antonym = g_slice_new0(WNIAntonymItem);
 						antonym->term = g_strdup(ant_synset->words[0]);
 						antonym->sense = ant_synset->wnsns[synptr->pto[i] - 1] - 1;				// - 1 is to make it count from 0 and not 1
 						antonym->relation = DIRECT_ANT;
@@ -330,7 +302,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 						if(NULL == check_term_in_list(ant_synset->words[j], &antonym->implications, 0))
 						{
 							//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-							implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+							implication = g_slice_new0(WNIImplication);
 							implication->term = g_strdup(ant_synset->words[j]);
 							implication->sense = ant_synset->wnsns[j] - 1;
 						
@@ -354,7 +326,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 								(NULL == check_term_in_list(sim_synset->words[k], &temp_list, 0)))
 								{
 									//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-									implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+									implication = g_slice_new0(WNIImplication);
 									implication->term = g_strdup(sim_synset->words[k]);
 									implication->sense = sim_synset->wnsns[k] - 1;
 						
@@ -370,7 +342,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 				    	antonym->implications = g_slist_concat(antonym->implications, temp_list);
 
 					//antonym_mapping = (WNIAntonymMapping*) g_malloc0(sizeof(WNIAntonymMapping));
-					antonym_mapping = (WNIAntonymMapping*) g_slice_alloc0(sizeof(WNIAntonymMapping));
+					antonym_mapping = g_slice_new0(WNIAntonymMapping);
 					antonym_mapping->id = id;
 					antonym_mapping->sense = sense;
 					antonym_mapping->related_word_count = count;	// - 1 is to make it count from 0 and not 1
@@ -392,11 +364,12 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 						{
 							antonym = (WNIAntonymItem*) temp_list->data;
 							g_free(temp_str);
+							temp_str = NULL;
 						}
 						else
 						{
 							//antonym = (WNIAntonymItem*) g_malloc0(sizeof(WNIAntonymItem));
-							antonym = (WNIAntonymItem*) g_slice_alloc0(sizeof(WNIAntonymItem));
+							antonym = g_slice_new0(WNIAntonymItem);
 							antonym->term = temp_str;
 							antonym->sense = count;
 							antonym->relation = INDIRECT_ANT;
@@ -414,7 +387,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 							(NULL == check_term_in_list(ant_synset->words[j], &temp_list, 0)))
 							{
 								//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-								implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+								implication = g_slice_new0(WNIImplication);
 								implication->term = g_strdup(ant_synset->words[j]);
 								implication->sense = ant_synset->wnsns[j] - 1;
 				
@@ -428,7 +401,7 @@ static void populate_adj_antonyms(SynsetPtr synptr, WNIProperties **antonyms_ptr
 					    	antonym->implications = g_slist_concat(antonym->implications, temp_list);
 
 						//antonym_mapping = (WNIAntonymMapping*) g_malloc0(sizeof(WNIAntonymMapping));
-						antonym_mapping = (WNIAntonymMapping*) g_slice_alloc0(sizeof(WNIAntonymMapping));
+						antonym_mapping = g_slice_new0(WNIAntonymMapping);
 						antonym_mapping->id = id;
 						antonym_mapping->sense = sense;
 						antonym_mapping->related_word_count = count;	// - 1 is to make it count from 0 and not 1
@@ -471,7 +444,7 @@ static gchar* parse_definition(gchar *str)
 	gchar ch = 0;
 	gchar *temp_ch = NULL;
 
-	len = g_utf8_strlen(str, -1) - 1;	// skip the last close brace (len - 1)
+	len = strlen(str) - 1;	// skip the last close brace (len - 1)
 	formatted_str = g_string_new("");
 	for(i = 1; i < len; i++)		// skip the first open brace (i = 1)
 	{
@@ -549,12 +522,12 @@ static gint pos_list_compare(gconstpointer a, gconstpointer b, gpointer actual_s
 
 	WNIDefinitionItem *defn_item_a = (WNIDefinitionItem*) a, *defn_item_b = (WNIDefinitionItem*) b;
 
-	not_equal = wni_strcmp0(defn_item_a->lemma, defn_item_b->lemma);
+	not_equal = g_strcmp0(defn_item_a->lemma, defn_item_b->lemma);
 	if(not_equal)
 	{
-		if(0 == wni_strcmp0((gchar*) actual_search, defn_item_a->lemma))		// Actual search str compared against item a and b's lemma
+		if(0 == g_strcmp0((gchar*) actual_search, defn_item_a->lemma))		// Actual search str compared against item a and b's lemma
 			return -1;
-		else if (0 == wni_strcmp0((gchar*) actual_search, defn_item_b->lemma))
+		else if (0 == g_strcmp0((gchar*) actual_search, defn_item_b->lemma))
 			return 1;
 	}
 
@@ -590,7 +563,7 @@ static GSList* check_term_in_list(gchar *term, GSList **list, WNIRequestFlags fl
 	gchar *temp_str = NULL;
 	glong check_len = 0;
 	
-	check_len = g_utf8_strlen(term, -1) + 1;	// check till \0 so that "Kelly" & "Kelly Gene" don't match
+	check_len = strlen(term) + 1;	// check till \0 so that "Kelly" & "Kelly Gene" don't match
 
 	while(temp)
 	{
@@ -634,7 +607,7 @@ static gboolean is_synm_a_lemma(GSList **list, gchar *synm)
 		{
 			temp_def_item = (WNIDefinitionItem*) temp_list->data;
 
-			if(0 == wni_strcmp0(temp_def_item->lemma, synm))
+			if(0 == g_strcmp0(temp_def_item->lemma, synm))
 				return TRUE;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -660,7 +633,7 @@ static gchar *get_example(gchar *offset, gchar *wd)
 			while(*line != ' ')
 				line++;
 
-			last_char_index = g_utf8_strlen(line, -1) - 1;
+			last_char_index = strlen(line) - 1;
 			// The last char is mostly a new line char. from file hence truncate it. If not we are dealing with the last line in the examples file :)
 			line[last_char_index] = (line[last_char_index]=='\n')? '\0' : line[last_char_index];
 			example = g_strdup_printf(g_strstrip(line), wd);
@@ -695,13 +668,13 @@ static GSList *find_example(SynsetPtr synptr)
 		{
 			// skip over sense key and get sentence numbers
 
-			temp += g_utf8_strlen(synptr->words[wdnum], -1) + 11;
+			temp += strlen(synptr->words[wdnum]) + 11;
 			g_stpcpy(tbuf, temp);
 			
 			splits = g_strsplit_set(tbuf, " ,\n", 0);
 			while(splits[i])
 			{
-				if(0 != wni_strcmp0(splits[i], ""))
+				if(0 != g_strcmp0(splits[i], ""))
 					if((returned_example = get_example(splits[i], synptr->words[wdnum])))
 						examples = g_slist_prepend(examples, returned_example);
 				i++;
@@ -737,16 +710,16 @@ static gpointer *get_from_global_list(WNIRequestFlags flag)
 
 	// Either the whole global list is null or there is no item with such ID.
 	//temp_nym = (WNINym*) g_malloc0(sizeof(WNINym));
-	temp_nym = (WNINym*) g_slice_alloc(sizeof(WNINym));
+	temp_nym = g_slice_new(WNINym);
 	temp_nym->id = flag;
 
 	if(WORDNET_INTERFACE_OVERVIEW & flag)
-		temp_nym->data = g_slice_alloc0(sizeof(WNIOverview));
+		temp_nym->data = g_slice_new0(WNIOverview);
 		//temp_nym->data = g_malloc0(sizeof(WNIOverview));
 	else/* if((WORDNET_INTERFACE_ANTONYMS & flag) || (WORDNET_INTERFACE_ATTRIBUTES & flag) || (WORDNET_INTERFACE_CAUSES & flag) || (WORDNET_INTERFACE_ENTAILS & flag) || 
 	(WORDNET_INTERFACE_SIMILAR & flag) || (WORDNET_INTERFACE_DERIVATIONS & flag) || (WORDNET_INTERFACE_PERTAINYMS & flag) || (WORDNET_INTERFACE_CLASS & flag) || 
 	(WORDNET_INTERFACE_HYPERNYMS & flag) || (WORDNET_INTERFACE_HYPONYMS & flag) || (WORDNET_INTERFACE_MERONYMS & flag) || (WORDNET_INTERFACE_HOLONYMS & flag))*/
-		temp_nym->data = g_slice_alloc0(sizeof(WNIProperties));
+		temp_nym->data = g_slice_new0(WNIProperties);
 		//temp_nym->data = g_malloc0(sizeof(WNIProperties));
 
 	// append it to the global_list and not temp_global_list, since it will be pointing to NULL by now
@@ -788,8 +761,8 @@ static void prune_results(void)
 				G_MESSAGE("Pruned: %d\n", temp_nym->id);
 				//g_free(temp_nym->data);
 				//g_free(temp_nym);
-				g_slice_free1(sizeof(WNIProperties), temp_nym->data);
-				g_slice_free1(sizeof(WNINym), temp_nym);
+				g_slice_free(WNIProperties, temp_nym->data);
+				g_slice_free(WNINym, temp_nym);
 				temp_nym = NULL;
 				global_list = g_slist_delete_link(global_list, temp_list);
 				temp_list = temp_prev;		// Reach the prev. node and continue normally
@@ -803,7 +776,7 @@ static void prune_results(void)
 
 /*
 	Creates the definition item for storing the definition, examples, synonyms and mapping.
-	In case if the term is already a synonym, remove that synonym alone from the synonyms list.
+	In case if the term is already a synonym, removes that synonym alone from the synonyms list.
 */
 
 static WNIDefinitionItem *create_synonym_def(guint8 pos, IndexPtr index, WNIOverview **overview_ptr)
@@ -821,13 +794,14 @@ static WNIDefinitionItem *create_synonym_def(guint8 pos, IndexPtr index, WNIOver
 
 	// Create a definition item to store the definition, its POS. Note ID is the unique ID which the synonym's list maps to for cross ref.
 	//def_item = (WNIDefinitionItem*) g_malloc0 (sizeof(WNIDefinitionItem));
-	def_item = (WNIDefinitionItem*) g_slice_alloc0 (sizeof(WNIDefinitionItem));
+	def_item = g_slice_new0(WNIDefinitionItem);
 	def_item->pos = pos;
 	def_item->lemma = g_strdup(mutable_lemma);
 	def_item->definitions = NULL;					// List to store the definitions & examples associated to it
 	def_item->id = g_slist_length(overview->definitions_list);	// First time call will give 0, since it will be NULL; next time onwards it will be 1, 2, so on..
 
 	g_free(mutable_lemma);
+	mutable_lemma = NULL;
 	// Check for already added synonyms, if it is the current lemma added. If found, remove them, since they will be definitions when we are done, and not synonyms
 	// e.g. axes => axe should be upgraded from synonym to lemma state
 	if(overview->synonyms_list)
@@ -852,7 +826,7 @@ static WNIDefinitionItem *create_synonym_def(guint8 pos, IndexPtr index, WNIOver
 	Populates the definition, examples and synonyms for WNI Overview.
 */
 
-static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr index, WNIDefinitionItem **def_item_ptr, WNIOverview **overview_ptr, guint8 sense, guint8 pos)
+static void populate_synonyms(WNIDefinitionItem **def_item_ptr, SynsetPtr cursyn, IndexPtr index, WNIOverview **overview_ptr, guint8 sense, guint8 pos)
 {
 	WNIDefinition *defn = NULL;
 	gchar *temp_str = NULL, **splits = NULL;
@@ -863,10 +837,11 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 	WNIOverview *overview = *overview_ptr;
 	guint16 i = 0;
 	glong check_len = 0;
+	gchar **lemma_ptr = &def_item->lemma;
 	gchar *lemma = *lemma_ptr;
 
 	//defn = (WNIDefinition*) g_malloc0 (sizeof(WNIDefinition));
-	defn = (WNIDefinition*) g_slice_alloc0 (sizeof(WNIDefinition));
+	defn = g_slice_new0(WNIDefinition);
 
 	if (index->tagged_cnt != -1 && ((sense + 1) <= index->tagged_cnt))	// a tag_count is present, overwrite the default 0
 		defn->tag_count = GetTagcnt(index, sense + 1);
@@ -877,7 +852,7 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 	defn->definition = g_strdup(splits[0]);
 
 	for(i = 1; splits[i]; i++)
-		if(wni_strcmp0(splits[i], ""))		// make sure examples are not null strings
+		if(g_strcmp0(splits[i], ""))		// make sure examples are not null strings
 			defn->examples = g_slist_prepend(defn->examples, g_strdup(splits[i]));
 
 	defn->examples = g_slist_reverse(defn->examples);
@@ -894,7 +869,7 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 	def_item->definitions = g_slist_prepend(def_item->definitions, defn);	// with this, definitions_list section is over, remaining is synonyms_list appending/mapping
 	def_item->count++;
 	
-	check_len = g_utf8_strlen(lemma, -1) + 1;
+	check_len = strlen(lemma) + 1;
 
 	for(i = 0; i < cursyn->wcount; i++)
 	{
@@ -911,7 +886,7 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 		if(g_ascii_strncasecmp(lemma, temp_str, check_len))	// Additional check to see if the current lemma and synm aren't the same
 		{
 			//mapping = (WNISynonymMapping*) g_malloc0 (sizeof(WNISynonymMapping));
-			mapping = (WNISynonymMapping*) g_slice_alloc0 (sizeof(WNISynonymMapping));
+			mapping = g_slice_new0(WNISynonymMapping);
 
 			mapping->id = def_item->id;
 			mapping->sense = sense;
@@ -929,8 +904,8 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 			else
 			{
 				//synm = (WNISynonym*) g_malloc0 (sizeof(WNISynonym));
-				//synm = (WNISynonym*) g_slice_alloc0 (sizeof(WNISynonym));
-				synm = (WNIPropertyItem*) g_slice_alloc0 (sizeof(WNIPropertyItem));
+				//synm = g_slice_new0(WNISynonym);
+				synm = g_slice_new0(WNIPropertyItem);
 				synm->term = g_strdup(temp_str);
 				synm->mapping = g_slist_append(synm->mapping, mapping);
 				overview->synonyms_list = g_slist_append(overview->synonyms_list, synm);
@@ -941,7 +916,7 @@ static void populate_synonyms(gchar **lemma_ptr, SynsetPtr cursyn, IndexPtr inde
 			// for cases where search is like 'wordsworth', substitute the proper case equivalent, provided if its the prime defn.
 			// I.e. if its the first defn. of the whole group. Since every defn. is prepended this is found by checking the next ptr of the list.
 			// If next is there, it means earlier there were defns before this one, else this is the first defn.
-			if(0 != wni_strcmp0(lemma, temp_str) && NULL == g_slist_next(def_item->definitions))
+			if(0 != g_strcmp0(lemma, temp_str) && NULL == g_slist_next(def_item->definitions))
 			{
 				g_free(lemma);
 				*lemma_ptr = g_strdup(temp_str);
@@ -974,7 +949,7 @@ static gboolean add_synonym_def(WNIDefinitionItem **def_item_ptr, WNIOverview **
 	{
 		g_free(def_item->lemma); def_item->lemma = NULL;
 		//g_free(def_item); def_item = NULL;
-		g_slice_free1(sizeof(WNIDefinitionItem), def_item); *def_item_ptr = NULL;
+		g_slice_free(WNIDefinitionItem, def_item); *def_item_ptr = NULL;
 	}
 
 	return FALSE;
@@ -998,7 +973,7 @@ static void populate_ptr(gchar *lemma, SynsetPtr synptr, WNIProperties **data_pt
 	guint16 i = 0, j = 0;
 	glong check_len = 0;
 	
-	check_len = g_utf8_strlen(lemma, -1) + 1;
+	check_len = strlen(lemma) + 1;
 
 	for(i = 0; i < synptr->ptrcount; i++)
 	{
@@ -1029,13 +1004,13 @@ static void populate_ptr(gchar *lemma, SynsetPtr synptr, WNIProperties **data_pt
 						else
 						{
 							//item = (WNIPropertyItem*) g_malloc0(sizeof(WNIPropertyItem));
-							item = (WNIPropertyItem*) g_slice_alloc0(sizeof(WNIPropertyItem));
+							item = g_slice_new0(WNIPropertyItem);
 							item->term = g_strdup(cursyn->words[j]);
 							properties->properties_list = g_slist_append(properties->properties_list, item);
 						}
 						temp_list = NULL;
 						//mapping = (WNIPropertyMapping*) g_malloc0(sizeof(WNIPropertyMapping));
-						mapping = (WNIPropertyMapping*) g_slice_alloc0(sizeof(WNIPropertyMapping));
+						mapping = g_slice_new0(WNIPropertyMapping);
 						mapping->self_sense = cursyn->wnsns[j] - 1;
 						mapping->id = id;
 						mapping->sense = sense;
@@ -1047,7 +1022,7 @@ static void populate_ptr(gchar *lemma, SynsetPtr synptr, WNIProperties **data_pt
 						if(NULL == temp_list)
 						{
 							//class_item = (WNIClassItem*) g_malloc0(sizeof(WNIClassItem));
-							class_item = (WNIClassItem*) g_slice_alloc0(sizeof(WNIClassItem));
+							class_item = g_slice_new0(WNIClassItem);
 							class_item->term = g_strdup(cursyn->words[j]);
 							class_item->self_sense = cursyn->wnsns[j] - 1;
 							class_item->self_pos = synptr->ppos[i];
@@ -1095,21 +1070,20 @@ static void grow_tree(gchar *lemma, SynsetPtr synptr, guint8 ptr, GNode **root,
 				if(cursyn->sstype != 0)
 					strip_adj_marker(cursyn->words[j]);
 				strsubst(cursyn->words[j], '_', ' ');
-				// what if no words are present except the actual lemma searched? so duplicate check is commented here e.g. hypernyms for 'register'
-				//if(0 != g_ascii_strncasecmp(lemma, cursyn->words[j], g_utf8_strlen(cursyn->words[j], -1) + 1))
-				//{
+				if(0 != g_ascii_strncasecmp(lemma, cursyn->words[j], strlen(cursyn->words[j]) + 1))
+				{
 					//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-					implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+					implication = g_slice_new0(WNIImplication);
 					implication->term = g_strdup(cursyn->words[j]);
 					implication->sense = cursyn->wnsns[j] - 1;
 					node_list = g_slist_prepend(node_list, implication);
-				//}
+				}
 			}
 
 			if(node_list)
 			{
 				//tree_list = (WNITreeList*) g_malloc0(sizeof(WNITreeList));
-				tree_list = (WNITreeList*) g_slice_alloc0(sizeof(WNITreeList));
+				tree_list = g_slice_new0(WNITreeList);
 				tree_list->word_list = g_slist_reverse(node_list);
 				tree_list->type = synptr->ptrtyp[i];			// store the actual ptr's type here. E.g. INSTANCE, HASPARTPTR, etc.
 
@@ -1163,22 +1137,21 @@ static void trace_inherit(gchar *lemma, SynsetPtr synptr, GNode **root, guint8 d
 				if(cursyn->sstype != 0)
 					strip_adj_marker(cursyn->words[j]);
 				strsubst(cursyn->words[j], '_', ' ');
-				// what if no words are present except the actual lemma searched? so duplicate check is commented here
-				//if(0 != g_ascii_strncasecmp(lemma, cursyn->words[j], g_utf8_strlen(cursyn->words[j], -1) + 1))
-				//{
+				if(0 != g_ascii_strncasecmp(lemma, cursyn->words[j], strlen(cursyn->words[j]) + 1))
+				{
 					//implication = (WNIImplication*) g_malloc0(sizeof(WNIImplication));
-					implication = (WNIImplication*) g_slice_alloc0(sizeof(WNIImplication));
+					implication = g_slice_new0(WNIImplication);
 					implication->term = g_strdup(cursyn->words[j]);
 					implication->sense = cursyn->wnsns[j] - 1;
 
 					node_list = g_slist_prepend(node_list, implication);
-				//}
+				}
 			}
 
 			if(node_list)
 			{
 				//tree_list = (WNITreeList*) g_malloc0(sizeof(WNITreeList));
-				tree_list = (WNITreeList*) g_slice_alloc0(sizeof(WNITreeList));
+				tree_list = g_slice_new0(WNITreeList);
 				tree_list->word_list = g_slist_reverse(node_list);
 				tree_list->type = 0;
 
@@ -1208,7 +1181,7 @@ static void trace_inherit(gchar *lemma, SynsetPtr synptr, GNode **root, guint8 d
 						g_slist_free(tree_list->word_list);
 						tree_list->word_list = NULL;
 						//g_free(tree_list);
-						g_slice_free1(sizeof(WNITreeList), tree_list);
+						g_slice_free(WNITreeList, tree_list);
 						tree_list = NULL;
 						g_node_destroy(cur_tree);
 						cur_tree = NULL;
@@ -1239,7 +1212,7 @@ static void populate_ptr_tree(gchar *lemma, SynsetPtr synptr, WNIProperties **da
 	if(HYPERPTR == ptr || HYPOPTR == ptr || HMERONYM == ptr || HHOLONYM == ptr || PERTPTR == ptr)
 	{
 		//tree_mapping = (WNISynonymMapping*) g_malloc0(sizeof(WNISynonymMapping));
-		tree_mapping = (WNISynonymMapping*) g_slice_alloc0(sizeof(WNISynonymMapping));
+		tree_mapping = g_slice_new0(WNISynonymMapping);
 		tree_mapping->id = id;
 		tree_mapping->sense = sense;
 
@@ -1280,6 +1253,7 @@ static void populate_ptr_tree(gchar *lemma, SynsetPtr synptr, WNIProperties **da
 			}
 
 			g_free(lemma);	// free the copy created for HOLO/MERO
+			lemma = NULL;
 		}
 		else
 		{
@@ -1290,7 +1264,7 @@ static void populate_ptr_tree(gchar *lemma, SynsetPtr synptr, WNIProperties **da
 		if(G_NODE_IS_LEAF(tree))
 		{
 			//g_free(tree_mapping);
-			g_slice_free1(sizeof(WNISynonymMapping), tree_mapping);
+			g_slice_free(WNISynonymMapping, tree_mapping);
 			g_node_destroy(tree);
 		}
 		else
@@ -1377,7 +1351,7 @@ static void populate(gchar *lemma, guint8 pos, WNIRequestFlags flag, gchar *actu
 				cursyn = read_synset(pos, index->offset[sense], index->wd);
 
 				if(WORDNET_INTERFACE_OVERVIEW & flag)
-					populate_synonyms(&def_item->lemma, cursyn, index, &def_item, &overview, sense, def_item->pos);
+					populate_synonyms(&def_item, cursyn, index, &overview, sense, def_item->pos);
 
 				if((WORDNET_INTERFACE_ANTONYMS & flag) && antonyms)
 				{
@@ -1398,10 +1372,8 @@ static void populate(gchar *lemma, guint8 pos, WNIRequestFlags flag, gchar *actu
 
 				if((WORDNET_INTERFACE_SIMILAR & flag) && similar) //(ADJ == pos))
 				{
-					// nouns & verbs don't have a SIMPTR defined explicitly, HYPERPTR is used instead, with 0 depth
-					if(NOUN == pos || VERB == pos)
-						populate_ptr(def_item->lemma, cursyn, &similar, HYPERPTR, def_item->id, sense, WORDNET_INTERFACE_SIMILAR);
-					else
+					// nouns & verbs don't have a SIMPTR defined
+					if((NOUN != pos) && (VERB != pos))
 						populate_ptr(def_item->lemma, cursyn, &similar, SIMPTR, def_item->id, sense, WORDNET_INTERFACE_SIMILAR);
 				}
 
@@ -1473,10 +1445,10 @@ gboolean wni_request_nyms(gchar *search_str, GSList **response_list, WNIRequestF
 		/* apart from checking for the length to be non-zero, checks for the search_str to be not ".", "-" and "_" 
 		 * are put up since is_defined() returns success for these actually futile searches; alternatively in_wn() 
 		 * can be also be used to check if a search_str is avaiable in WN; it rightly returns 0 for these 'strings' */
-		if(	g_utf8_strlen(search_str, -1) > 0 && 
-			wni_strcmp0(search_str, ".") && 
-			wni_strcmp0(search_str, "-") && 
-			wni_strcmp0(search_str, "_") )
+		if(	strlen(search_str) > 0 && 
+			g_strcmp0(search_str, ".") && 
+			g_strcmp0(search_str, "-") && 
+			g_strcmp0(search_str, "_") )
 		{
 			for(i = 1; i <= NUMPARTS; i++)
 			{
@@ -1516,6 +1488,7 @@ gboolean wni_request_nyms(gchar *search_str, GSList **response_list, WNIRequestF
 		}
 
 		g_free(search_str);
+		search_str = NULL;
 		// once all the requests are generated, prune the results
 		prune_results();
 
@@ -1540,9 +1513,11 @@ gboolean wni_request_nyms(gchar *search_str, GSList **response_list, WNIRequestF
 static void simple_list_free(GSList **list, guint8 mode)
 {
 	GSList *temp_list = *list;
+#if DEBUG_LEVEL > 2
 	WNISynonymMapping *synonym_mapping = NULL;
 	WNIAntonymMapping *antonym_mapping = NULL;
 	WNIPropertyMapping *property_mapping = NULL;
+#endif
 
 	while(temp_list)
 	{
@@ -1550,21 +1525,27 @@ static void simple_list_free(GSList **list, guint8 mode)
 		{
 			if(SYNONYM_MAPPING == mode)
 			{
+#if DEBUG_LEVEL > 2
 				synonym_mapping = (WNISynonymMapping*) temp_list->data;
 				G_PRINTF("(%d, %d)\n", synonym_mapping->id, synonym_mapping->sense);
-				g_slice_free1(sizeof(WNISynonymMapping), temp_list->data);
+#endif
+				g_slice_free(WNISynonymMapping, temp_list->data);
 			}
 			else if(ANTONYM_MAPPING == mode)
 			{
+#if DEBUG_LEVEL > 2
 				antonym_mapping = (WNIAntonymMapping*) temp_list->data;
 				G_PRINTF("ID: %d, Sense: %d, Related Word Count: %d\n", antonym_mapping->id, antonym_mapping->sense, antonym_mapping->related_word_count);
-				g_slice_free1(sizeof(WNIAntonymMapping), temp_list->data);
+#endif
+				g_slice_free(WNIAntonymMapping, temp_list->data);
 			}
 			else if(PROPERTY_MAPPING == mode)
 			{
+#if DEBUG_LEVEL > 2
 				property_mapping = (WNIPropertyMapping*) temp_list->data;
 				G_PRINTF("ID: %d, Sense: %d, Self Sense: %d\n", property_mapping->id, property_mapping->sense, property_mapping->self_sense);
-				g_slice_free1(sizeof(WNIPropertyMapping), temp_list->data);
+#endif
+				g_slice_free(WNIPropertyMapping, temp_list->data);
 			}
 			else
 			{
@@ -1609,8 +1590,8 @@ static void synonym_list_free(GSList **list, gboolean single_element)
 
 			g_free(temp_synonym->term);
 			//g_free(temp_synonym);
-			//g_slice_free1(sizeof(WNISynonym), temp_synonym);
-			g_slice_free1(sizeof(WNIPropertyItem), temp_synonym);
+			//g_slice_free(WNISynonym, temp_synonym);
+			g_slice_free(WNIPropertyItem, temp_synonym);
 			temp_synonym = temp_list->data = NULL;
 		}
 		temp_list = single_element?NULL:g_slist_next(temp_list);	// if single_element set, stop traversal.
@@ -1641,7 +1622,7 @@ static void definitions_free(GSList **list)
 			}
 			g_free(temp_def->definition);
 			//g_free(temp_def);
-			g_slice_free1(sizeof(WNIDefinition), temp_def);
+			g_slice_free(WNIDefinition, temp_def);
 			temp_def = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1673,7 +1654,7 @@ static void definitions_list_free(GSList **list)
 
 			g_free(tmp_def_item->lemma);
 			//g_free(tmp_def_item);
-			g_slice_free1(sizeof(WNIDefinitionItem), tmp_def_item);
+			g_slice_free(WNIDefinitionItem, tmp_def_item);
 			tmp_def_item = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1701,7 +1682,7 @@ static void implications_free(GSList **list, guint8 mode)
 
 			g_free(temp_implication->term);
 			//g_free(temp_implication);
-			g_slice_free1(sizeof(WNIImplication), temp_implication);
+			g_slice_free(WNIImplication, temp_implication);
 			temp_implication = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1732,7 +1713,7 @@ static void antonyms_list_free(GSList **list)
 			g_slist_free(temp_antonym->implications);
 			g_free(temp_antonym->term);
 			//g_free(temp_antonym);
-			g_slice_free1(sizeof(WNIAntonymItem), temp_antonym);
+			g_slice_free(WNIAntonymItem, temp_antonym);
 			temp_antonym = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1770,7 +1751,7 @@ static void properties_list_free(GSList **list, WNIRequestFlags id)
 			g_slist_free(temp_property->mapping);
 			g_free(temp_property->term);
 			//g_free(temp_property);
-			g_slice_free1(sizeof(WNIPropertyItem), temp_property);
+			g_slice_free(WNIPropertyItem, temp_property);
 			temp_property = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1796,22 +1777,22 @@ static void class_list_free(GSList **list)
 			switch(temp_class_item->type)
 			{
 				case CLASSIF_CATEGORY:
-					G_PRINTF("Topic: ", NULL);
+					G_PRINTF("Topic: ");
 					break;
 				case CLASSIF_USAGE:
-					G_PRINTF("Usage: ", NULL);
+					G_PRINTF("Usage: ");
 					break;
 				case CLASSIF_REGIONAL:
-					G_PRINTF("Region: ", NULL);
+					G_PRINTF("Region: ");
 					break;
 				case CLASS_CATEGORY:
-					G_PRINTF("Topic Term: ", NULL);
+					G_PRINTF("Topic Term: ");
 					break;
 				case CLASS_USAGE:
-					G_PRINTF("Usage Term: ", NULL);
+					G_PRINTF("Usage Term: ");
 					break;
 				case CLASS_REGIONAL:
-					G_PRINTF("Regional Term: ", NULL);
+					G_PRINTF("Regional Term: ");
 					break;
 			}
 			G_PRINTF("(%c) %s#%d -> ID: %d, Sense: %d\n", partchars[temp_class_item->self_pos], 
@@ -1819,7 +1800,7 @@ static void class_list_free(GSList **list)
 
 			g_free(temp_class_item->term);
 			//g_free(temp_class_item);
-			g_slice_free1(sizeof(WNIClassItem), temp_class_item);
+			g_slice_free(WNIClassItem, temp_class_item);
 			temp_class_item = temp_list->data = NULL;
 		}
 		temp_list = g_slist_next(temp_list);
@@ -1855,14 +1836,14 @@ static gboolean node_free(GNode *node, gpointer data)
 
 				g_free(implication->term);
 				//g_free(temp_list->data);
-				g_slice_free1(sizeof(WNIImplication), temp_list->data);
+				g_slice_free(WNIImplication, temp_list->data);
 				implication = temp_list->data = NULL;
 			}
 			temp_list = g_slist_next(temp_list);
 		}
 		g_slist_free(temp_tree_list->word_list);
 		//g_free(node->data);
-		g_slice_free1(sizeof(WNITreeList), node->data);
+		g_slice_free(WNITreeList, node->data);
 		temp_tree_list = node->data = NULL;
 	}
 	
@@ -1890,13 +1871,16 @@ static void properties_tree_free(GSList **list, WNIRequestFlags id)
 {
 	GNode *tree_root = NULL;
 	GSList *temp_list = *list;
+#if DEBUG_LEVEL > 2
 	WNISynonymMapping *mapping  = NULL;
+#endif
 	
 	while(temp_list)
 	{
 		if(temp_list->data)
 		{
 			tree_root = (GNode*) temp_list->data;
+#if DEBUG_LEVEL > 2
 			mapping = (WNISynonymMapping*) tree_root->data;
 
 			if(WORDNET_INTERFACE_HYPERNYMS & id)
@@ -1909,10 +1893,12 @@ static void properties_tree_free(GSList **list, WNIRequestFlags id)
 				G_PRINTF("Holonyms: %d, %d\n", mapping->id, mapping->sense);
 			else if (WORDNET_INTERFACE_PERTAINYMS & id)
 				G_PRINTF("Pertains: %d, %d\n", mapping->id, mapping->sense);
-
+            
+            mapping = NULL;
+#endif
 			//g_free(tree_root->data);
-			g_slice_free1(sizeof(WNISynonymMapping), tree_root->data);
-			mapping = tree_root->data = NULL;
+			g_slice_free(WNISynonymMapping, tree_root->data);
+			tree_root->data = NULL;
 			g_node_children_foreach(tree_root, G_TRAVERSE_ALL, tree_free, NULL);
 			g_node_destroy(tree_root);
 		}
@@ -1960,7 +1946,7 @@ void wni_free(GSList **response_list)
 						temp_overview->synonyms_list = NULL;
 
 						//g_free(temp_nym->data); temp_nym->data = NULL;
-						g_slice_free1(sizeof(WNIOverview), temp_nym->data);
+						g_slice_free(WNIOverview, temp_nym->data);
 						temp_overview = temp_nym->data = NULL;
 					}
 					break;
@@ -1978,7 +1964,7 @@ void wni_free(GSList **response_list)
 						temp_antonyms->properties_list = NULL;
 						
 						//g_free(temp_nym->data); temp_nym->data = NULL;
-						g_slice_free1(sizeof(WNIProperties), temp_nym->data);
+						g_slice_free(WNIProperties, temp_nym->data);
 						temp_antonyms = temp_nym->data = NULL;
 					}
 					break;
@@ -2004,7 +1990,7 @@ void wni_free(GSList **response_list)
 						temp_properties->properties_list = NULL;
 
 						//g_free(temp_nym->data); temp_nym->data = NULL;
-						g_slice_free1(sizeof(WNIProperties), temp_nym->data);
+						g_slice_free(WNIProperties, temp_nym->data);
 						temp_properties = temp_nym->data = NULL;
 					}
 					break;
@@ -2026,18 +2012,18 @@ void wni_free(GSList **response_list)
 						temp_properties->properties_list = NULL;
 						
 						//g_free(temp_nym->data); temp_nym->data = NULL;
-						g_slice_free1(sizeof(WNIProperties), temp_nym->data);
+						g_slice_free(WNIProperties, temp_nym->data);
 						temp_properties = temp_nym->data = NULL;
 					}
 					break;
 				}
 				default:
 					//g_free(temp_nym->data); temp_nym->data = NULL;	// should never reach here, since all the cases are handled above specifically
-					g_slice_free1(sizeof(WNIProperties), temp_nym->data); temp_nym->data = NULL;
+					g_slice_free(WNIProperties, temp_nym->data); temp_nym->data = NULL;
 					break;
 			}
 			//g_free(global_list->data); global_list->data = NULL;
-			g_slice_free1(sizeof(WNINym), global_list->data);
+			g_slice_free(WNINym, global_list->data);
 			temp_nym = global_list->data = NULL;
 		}
 		global_list = g_slist_next(global_list);
